@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2013-2025 Oracle and/or its affiliates.
  * This file is based on ast_drv.h
  * Copyright 2012 Red Hat Inc.
  *
@@ -188,10 +188,6 @@
 # include <drm/drm_framebuffer.h>
 #endif
 
-#if RTLNX_VER_MIN(6,19,0)
-#include <drm/drm_print.h>
-#endif
-
 #include "vboxvideo_guest.h"
 #include "vboxvideo_vbe.h"
 #include "hgsmi_ch_setup.h"
@@ -301,10 +297,6 @@ struct vbox_private {
 	} ttm;
 
 	struct mutex hw_mutex; /* protects modeset and accel/vbva accesses */
-#if RTLNX_VER_MIN(6,18,0)
-	/** Replacement for struct drm_device .struct_mutex. */
-	struct mutex struct_mutex;
-#endif
 	/**
 	 * We decide whether or not user-space supports display hot-plug
 	 * depending on whether they react to a hot-plug event after the initial
