@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2013-2025 Oracle and/or its affiliates.
  * This file is based on ast_main.c
  * Copyright 2012 Red Hat Inc.
  *
@@ -175,9 +175,8 @@ int vbox_framebuffer_init(struct drm_device *dev,
 {
 	int ret;
 
-#if RTLNX_VER_MIN(6,17,0) || RTLNX_RHEL_RANGE(9,8, 9,99) || RTLNX_RHEL_RANGE(10,1, 10,99)
-	const struct drm_format_info *format = drm_get_format_info(dev, mode_cmd->pixel_format, 0);
-	drm_helper_mode_fill_fb_struct(dev, &vbox_fb->base, format, mode_cmd);
+#if RTLNX_VER_MIN(6,17,0)
+	drm_helper_mode_fill_fb_struct(dev, &vbox_fb->base, NULL, mode_cmd);
 #elif RTLNX_VER_MIN(4,11,0) || RTLNX_RHEL_MAJ_PREREQ(7,5)
 	drm_helper_mode_fill_fb_struct(dev, &vbox_fb->base, mode_cmd);
 #else
@@ -196,7 +195,7 @@ int vbox_framebuffer_init(struct drm_device *dev,
 static struct drm_framebuffer *vbox_user_framebuffer_create(
 		struct drm_device *dev,
 		struct drm_file *filp,
-#if RTLNX_VER_MIN(6,17,0) || RTLNX_RHEL_RANGE(9,8, 9,99) || RTLNX_RHEL_RANGE(10,1, 10,99)
+#if RTLNX_VER_MIN(6,17,0)
 		const struct drm_format_info *info,
 #endif
 #if RTLNX_VER_MIN(4,5,0) || RTLNX_RHEL_MAJ_PREREQ(7,3)
@@ -480,9 +479,7 @@ int vbox_driver_load(struct drm_device *dev, unsigned long flags)
 	vbox->dev = dev;
 
 	mutex_init(&vbox->hw_mutex);
-#if RTLNX_VER_MIN(6,18,0)
-	mutex_init(&vbox->struct_mutex);
-#endif
+
 	ret = vbox_hw_init(vbox);
 	if (ret)
 		return ret;
@@ -553,10 +550,7 @@ void vbox_driver_lastclose(struct drm_device *dev)
 {
 	struct vbox_private *vbox = dev->dev_private;
 
-#if RTLNX_VER_MIN(6,19,0)
-	if (vbox->fbdev)
-		drm_fb_helper_restore_fbdev_mode_unlocked(&vbox->fbdev->helper, false);
-#elif RTLNX_VER_MIN(3,16,0) || RTLNX_RHEL_MAJ_PREREQ(7,1)
+#if RTLNX_VER_MIN(3,16,0) || RTLNX_RHEL_MAJ_PREREQ(7,1)
 	if (vbox->fbdev)
 		drm_fb_helper_restore_fbdev_mode_unlocked(&vbox->fbdev->helper);
 #else
@@ -654,11 +648,7 @@ void vbox_gem_free_object(struct drm_gem_object *obj)
 	}
 #endif
 
-#if RTLNX_VER_MIN(6,19,0)
-	ttm_bo_fini(&vbox_bo->bo);
-#else
 	ttm_bo_put(&vbox_bo->bo);
-#endif
 }
 
 static inline u64 vbox_bo_mmap_offset(struct vbox_bo *bo)
@@ -680,16 +670,8 @@ vbox_dumb_mmap_offset(struct drm_file *file,
 	struct drm_gem_object *obj;
 	int ret = 0;
 	struct vbox_bo *bo;
-	struct mutex *struct_mutex;
 
-#if RTLNX_VER_MIN(6,18,0)
-	struct vbox_private *vbox = dev->dev_private;
-	struct_mutex = &vbox->struct_mutex;
-#else
-	struct_mutex = &dev->struct_mutex;
-#endif
-
-	mutex_lock(struct_mutex);
+	mutex_lock(&dev->struct_mutex);
 #if RTLNX_VER_MIN(4,7,0) || RTLNX_RHEL_MAJ_PREREQ(7,4)
 	obj = drm_gem_object_lookup(file, handle);
 #else
@@ -713,6 +695,6 @@ vbox_dumb_mmap_offset(struct drm_file *file,
 	drm_gem_object_put(obj);
 
 out_unlock:
-	mutex_unlock(struct_mutex);
+	mutex_unlock(&dev->struct_mutex);
 	return ret;
 }
