@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2013-2025 Oracle and/or its affiliates.
  * This file is based on ast_ttm.c
  * Copyright 2012 Red Hat Inc.
  *
@@ -358,7 +358,7 @@ static int vbox_bo_move(struct ttm_buffer_object *bo, bool evict,
 	struct ttm_operation_ctx *ctx, struct ttm_resource *new_mem,
 	struct ttm_place *hop)
 {
-# if RTLNX_VER_MIN(6,4,0) || RTLNX_RHEL_RANGE(9,6, 9,99)
+# if RTLNX_VER_MIN(6,4,0) || RTLNX_RHEL_RANGE(9,7, 9,99)
 	if (!bo->resource) {
 		if (new_mem->mem_type != TTM_PL_SYSTEM) {
 			hop->mem_type = TTM_PL_SYSTEM;
@@ -447,15 +447,10 @@ int vbox_mm_init(struct vbox_private *vbox)
 #elif RTLNX_VER_MAX(5,2,0) && !RTLNX_RHEL_MAJ_PREREQ(8,2)
 				 DRM_FILE_PAGE_OFFSET,
 #endif
-#if RTLNX_VER_RANGE(5,11,0, 6,19,0) || RTLNX_RHEL_RANGE(8,5, 8,99)
+#if RTLNX_VER_MIN(5,11,0) || RTLNX_RHEL_RANGE(8,5, 8,99)
 				 false,
 #endif
-#if RTLNX_VER_MIN(6,19,0)
-				 TTM_ALLOCATION_POOL_USE_DMA32
-#else
-				 true
-#endif
-				 );
+				 true);
 	if (ret) {
 		DRM_ERROR("Error initialising bo driver; %d\n", ret);
 #if RTLNX_VER_MAX(5,0,0) && !RTLNX_RHEL_MAJ_PREREQ(7,7) && !RTLNX_RHEL_MAJ_PREREQ(8,1)
